API reference
=============


xemc3. module
-----------------

.. automodule:: xemc3.EMC3DatasetAccessor


xemc3.load module
-----------------

.. automodule:: xemc3.load


xemc3.write module
------------------

.. automodule:: xemc3.write.fortran
.. automodule:: xemc3.write.nc


xemc3.plot module
-----------------

.. automodule:: xemc3.plot
    :members:
    :undoc-members:
    :show-inheritance:
    :ignore-module-all:
    :private-members:
    :imported-members:
